/**** Includes ****/
#include "mcu/mcu_hal.h"
#include "memory.h"

using namespace bsp;

/**** Private definitions ****/
/**** Private constants ****/
/**** Private variables ****/
/**** Private function declarations ****/
/**** Public function definitions ****/
bsp::Memory::Memory(void)
{
	return;
}

bsp::Memory::~Memory(void)
{
	return;
}

uint8_t bsp::Memory::read_8b(uint16_t address)
{
	return mcu::eeprom_read8b(address);
}


uint16_t bsp::Memory::read_16b(uint16_t address)
{
	return mcu::eeprom_read16b(address);
}

uint32_t bsp::Memory::read_32b(uint16_t address)
{
	return mcu::eeprom_read32b(address);
}

void bsp::Memory::write_8b(uint16_t address, uint8_t value)
{
	mcu::eeprom_write8b(address, value);
}


void bsp::Memory::write_16b(uint16_t address, uint16_t value)
{
	mcu::eeprom_write16b(address, value);
}

void bsp::Memory::write_32b(uint16_t address, uint32_t value)
{
	mcu::eeprom_write32b(address, value);
}

/**** Private function definitions ****/

